``cone.app`` - Build Web Applications on top of the pyramid framework.


Detailed Documentation
======================

The detailed ``cone.app`` documentation is available 
`here <http://packages.python.org/cone.app>`_.


Source Code
===========

The sources are in a GIT DVCS with its main branches at 
`github <http://github.com/bluedynamics/cone.app>`_.


Copyright
=========

- Copyright (c) 2009-2017 BlueDynamics Alliance http://www.bluedynamics.com


Contributors
============

- Robert Niederreiter (Author)
- Jens Klein
- Georg Gogo. BERNHARD


Coverage Report
===============

::

    lines   cov%   module
      199   100%   cone.app.__init__
       29    96%   cone.app.browser.__init__
      275   100%   cone.app.browser.actions
      175    98%   cone.app.browser.ajax
      242    95%   cone.app.browser.authoring
      101   100%   cone.app.browser.batch
      151    94%   cone.app.browser.contents
       72    94%   cone.app.browser.contextmenu
      111   100%   cone.app.browser.copysupport
       24   100%   cone.app.browser.exception
       87    90%   cone.app.browser.form
      280    90%   cone.app.browser.layout
       63   100%   cone.app.browser.login
      212    95%   cone.app.browser.referencebrowser
       73    79%   cone.app.browser.resources
       40   100%   cone.app.browser.settings
      149    98%   cone.app.browser.sharing
      140   100%   cone.app.browser.table
       81    98%   cone.app.browser.utils
       50    96%   cone.app.browser.workflow
       70   100%   cone.app.interfaces
      375    93%   cone.app.model
      178   100%   cone.app.security
       88   100%   cone.app.testing.__init__
       45    93%   cone.app.testing.mock
       44   100%   cone.app.tests
       47   100%   cone.app.utils
       63   100%   cone.app.workflow
